package com.gprinter.utils;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.ColorMatrix;
import android.graphics.ColorMatrixColorFilter;
import android.graphics.Matrix;
import android.graphics.Paint;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/* loaded from: com_gprinter_utils.jar:com/gprinter/utils/BitmapUtils.class */
public class BitmapUtils {
    public static Bitmap thresholdBitmap(Bitmap img, boolean shake) {
        int height = img.getHeight();
        int width = img.getWidth();
        int[] pixels = thresholdBitmapPixels(img, shake);
        Bitmap mBitmap = Bitmap.createBitmap(width, height, img.getConfig());
        mBitmap.setPixels(pixels, 0, width, 0, 0, width, height);
        return mBitmap;
    }

    public static List<Bitmap> cutBitmapByHeight(Bitmap bitmap, int maxHeight) {
        List<Bitmap> list = new ArrayList<>();
        if (bitmap == null || maxHeight < 1) {
            return list;
        }
        int i = 0;
        while (true) {
            int startHeight = i;
            if (startHeight < bitmap.getHeight()) {
                int endHeight = startHeight + maxHeight;
                if (endHeight > bitmap.getHeight()) {
                    endHeight = bitmap.getHeight();
                }
                Bitmap sub = Bitmap.createBitmap(bitmap, 0, startHeight, bitmap.getWidth(), endHeight - startHeight);
                list.add(sub);
                i = startHeight + maxHeight;
            } else {
                return list;
            }
        }
    }

    public static byte[] addBytes(byte[] data1, byte[] data2) {
        byte[] data3 = new byte[data1.length + data2.length];
        System.arraycopy(data1, 0, data3, 0, data1.length);
        System.arraycopy(data2, 0, data3, data1.length, data2.length);
        return data3;
    }

    public static Bitmap resizeImage(Bitmap bitmap, int w, int h) {
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        float scaleWidth = w / width;
        float scaleHeight = h / height;
        Matrix matrix = new Matrix();
        matrix.postScale(scaleWidth, scaleHeight);
        return Bitmap.createBitmap(bitmap, 0, 0, width, height, matrix, true);
    }

    public static Bitmap resizeImageAndRotation(Bitmap bitmap, int w, int h) {
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        float scaleWidth = w / width;
        float scaleHeight = h / height;
        Matrix matrix = new Matrix();
        matrix.setScale(1.0f, -1.0f);
        matrix.postScale(scaleWidth, scaleHeight);
        return Bitmap.createBitmap(bitmap, 0, 0, width, height, matrix, true);
    }

    private static byte[] getBinaryzationBytes(Bitmap bitmap) {
        return getBinaryzationBytes(bitmap, 128, false);
    }

    private static byte[] getBinaryzationBytes(Bitmap bitmap, boolean reverse) {
        return getBinaryzationBytes(bitmap, 128, reverse);
    }

    private static byte[] getBinaryzationBytes(Bitmap bitmap, int threshold, boolean reverse) {
        if (bitmap == null) {
            return null;
        }
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        byte[] data = new byte[width * height];
        int[] pixels = new int[width * height];
        bitmap.getPixels(pixels, 0, width, 0, 0, width, height);
        for (int i = 0; i < height; i++) {
            for (int j = 0; j < width; j++) {
                int color = pixels[(i * width) + j];
                int gray = (int) ((0.299d * ((color & 16711680) >> 16)) + (0.587d * ((color & 65280) >> 8)) + (0.114d * (color & 255)));
                byte y = (byte) (reverse ? 1 : 0);
                byte n = (byte) (reverse ? 0 : 1);
                data[(i * width) + j] = gray < threshold ? y : n;
            }
        }
        return data;
    }

    public static byte[] getCompressedBinaryzationBytes(Bitmap bitmap) {
        return getCompressedBinaryzationBytes(bitmap, 128, false);
    }

    public static byte[] getCompressedBinaryzationBytes(Bitmap bitmap, boolean reverse) {
        return getCompressedBinaryzationBytes(bitmap, 128, reverse);
    }

    public static byte[] getCompressedBinaryzationBytes(Bitmap bitmap, int threshold, boolean reverse) {
        if (bitmap == null) {
            return null;
        }
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        int lineBytes = ((width - 1) / 8) + 1;
        byte[] data = new byte[lineBytes * height];
        byte[] imageBytes = getBinaryzationBytes(bitmap, threshold, reverse);
        for (int i = 0; i < height; i++) {
            for (int j = 0; j < lineBytes; j++) {
                byte unit = 0;
                for (int k = 0; k < 8; k++) {
                    if ((j << 3) + k < width) {
                        byte pixel = imageBytes[(i * width) + (j << 3) + k];
                        unit = (byte) (unit | ((pixel & 1) << (7 - k)));
                    }
                }
                data[(i * lineBytes) + j] = unit;
            }
        }
        return data;
    }

    public static Bitmap threshold(Bitmap img, boolean shake) {
        int e;
        Bitmap bmpGrayscale = Bitmap.createBitmap(img.getWidth(), img.getHeight(), img.getConfig());
        Canvas c = new Canvas(bmpGrayscale);
        Paint paint = new Paint();
        ColorMatrix cm = new ColorMatrix();
        cm.setSaturation(0.0f);
        ColorMatrixColorFilter f = new ColorMatrixColorFilter(cm);
        paint.setColorFilter(f);
        c.drawBitmap(img, 0.0f, 0.0f, paint);
        int width = bmpGrayscale.getWidth();
        int height = bmpGrayscale.getHeight();
        int[] pixels = new int[width * height];
        bmpGrayscale.getPixels(pixels, 0, width, 0, 0, width, height);
        int[] gray = new int[height * width];
        for (int i = 0; i < height; i++) {
            for (int j = 0; j < width; j++) {
                int grey = pixels[(width * i) + j];
                int red = (grey & 16711680) >> 16;
                gray[(width * i) + j] = red;
            }
        }
        for (int i2 = 0; i2 < height; i2++) {
            for (int j2 = 0; j2 < width; j2++) {
                int g = gray[(width * i2) + j2];
                if (g >= 128) {
                    pixels[(width * i2) + j2] = -1;
                    e = g - 255;
                } else {
                    pixels[(width * i2) + j2] = -16777216;
                    e = g - 0;
                }
                if (shake) {
                    if (j2 < width - 1 && i2 < height - 1) {
                        int i3 = (width * i2) + j2 + 1;
                        gray[i3] = gray[i3] + ((7 * e) / 16);
                        int i4 = (width * (i2 + 1)) + j2;
                        gray[i4] = gray[i4] + ((5 * e) / 16);
                        int i5 = (width * (i2 + 1)) + j2 + 1;
                        gray[i5] = gray[i5] + (e / 16);
                        if (j2 > 0) {
                            int i6 = ((width * (i2 + 1)) + j2) - 1;
                            gray[i6] = gray[i6] + ((3 * e) / 16);
                        }
                    } else if (j2 == width - 1 && i2 < height - 1) {
                        int i7 = (width * (i2 + 1)) + j2;
                        gray[i7] = gray[i7] + ((5 * e) / 16);
                    } else if (j2 < width - 1 && i2 == height - 1) {
                        int i8 = (width * i2) + j2 + 1;
                        gray[i8] = gray[i8] + ((7 * e) / 16);
                    }
                }
            }
        }
        Bitmap mBitmap = Bitmap.createBitmap(width, height, bmpGrayscale.getConfig());
        mBitmap.setPixels(pixels, 0, width, 0, 0, width, height);
        return mBitmap;
    }

    public static Bitmap filter(Bitmap src) {
        int i;
        int width = src.getWidth();
        int height = src.getHeight();
        int[] inPixels = new int[width * height];
        int[] outPixels = new int[width * height];
        src.getPixels(inPixels, 0, width, 0, 0, width, height);
        double redSum = 0.0d;
        double greenSum = 0.0d;
        double blueSum = 0.0d;
        double total = height * width;
        for (int row = 0; row < height; row++) {
            for (int col = 0; col < width; col++) {
                int index = (row * width) + col;
                int i2 = (inPixels[index] >> 24) & 255;
                int tr = (inPixels[index] >> 16) & 255;
                int tg = (inPixels[index] >> 8) & 255;
                int tb = inPixels[index] & 255;
                redSum += tr;
                greenSum += tg;
                blueSum += tb;
            }
        }
        int means = (int) (redSum / total);
        System.out.println(" threshold average value = " + means);
        for (int row2 = 0; row2 < height; row2++) {
            for (int col2 = 0; col2 < width; col2++) {
                int index2 = (row2 * width) + col2;
                int ta = (inPixels[index2] >> 24) & 255;
                int tr2 = (inPixels[index2] >> 16) & 255;
                int i3 = (inPixels[index2] >> 8) & 255;
                int i4 = inPixels[index2] & 255;
                if (tr2 >= means) {
                    i = 255;
                } else {
                    i = 0;
                }
                int tb2 = i;
                int tg2 = i;
                int tr3 = i;
                outPixels[index2] = (ta << 24) | (tr3 << 16) | (tg2 << 8) | tb2;
            }
        }
        Bitmap mBitmap = Bitmap.createBitmap(width, height, src.getConfig());
        mBitmap.setPixels(outPixels, 0, width, 0, 0, width, height);
        return mBitmap;
    }

    public static Bitmap resizeBitmap(Bitmap bitmap, int dstWidth, int dstHeight, boolean stretchBitmap) {
        Bitmap bitmap2;
        if (bitmap == null) {
            return null;
        }
        if (bitmap.getWidth() == dstWidth && bitmap.getHeight() == dstHeight) {
            return bitmap;
        }
        if (dstWidth < 1 || dstHeight < 1) {
            throw new IllegalArgumentException("Bitmap output width and height must greater than 1");
        }
        if (stretchBitmap) {
            float scaleX = dstWidth / bitmap.getWidth();
            float scaleY = dstHeight / bitmap.getHeight();
            Matrix matrix = new Matrix();
            matrix.postScale(scaleX, scaleY);
            bitmap2 = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true);
        } else {
            Bitmap paddingBitmap = Bitmap.createBitmap(dstWidth, dstHeight, bitmap.getConfig());
            Canvas canvas = new Canvas(paddingBitmap);
            canvas.drawColor(-1);
            canvas.drawBitmap(bitmap, 0.0f, 0.0f, (Paint) null);
            bitmap2 = paddingBitmap;
        }
        return bitmap2;
    }

    public static byte[] getDotMatrixOfBitmapForPrint(Bitmap bitmap, boolean shake) {
        return getDotMatrixOfBitmapForPrint(bitmap, shake, true);
    }

    public static byte[] getDotMatrixOfBitmapForPrint(Bitmap bitmap, boolean shake, boolean reverseBit) {
        int columnSize = (int) Math.ceil(bitmap.getWidth() / 8.0d);
        byte[] data = new byte[columnSize * bitmap.getHeight()];
        int dataIndex = 0;
        int height = bitmap.getHeight();
        int width = bitmap.getWidth();
        int[] pixels = thresholdBitmapPixels(bitmap, shake);
        for (int y = 0; y < height; y++) {
            for (int x = 0; x < columnSize; x++) {
                for (int dataBit = 0; dataBit < 8; dataBit++) {
                    int lineIndex = (x * 8) + dataBit;
                    if (lineIndex < width) {
                        int pixelColor = pixels[(y * width) + lineIndex];
                        int R = (pixelColor >> 16) & 255;
                        int G = (pixelColor >> 8) & 255;
                        int B = pixelColor & 255;
                        int GR = (int) ((R * 0.3f) + (G * 0.59f) + (B * 0.11f));
                        if (GR < 128) {
                            if (reverseBit) {
                                data[dataIndex] = (byte) ((data[dataIndex] << 1) | 1);
                            } else {
                                data[dataIndex] = (byte) ((data[dataIndex] << 1) & 254);
                            }
                        } else if (reverseBit) {
                            data[dataIndex] = (byte) ((data[dataIndex] << 1) & 254);
                        } else {
                            data[dataIndex] = (byte) ((data[dataIndex] << 1) | 1);
                        }
                    }
                }
                dataIndex++;
            }
        }
        return data;
    }

    public static byte[] getDotMatrixOfBitmapForPrintVertical(Bitmap bitmap, boolean shake) {
        byte[] data = new byte[(bitmap.getHeight() * bitmap.getWidth()) / 8];
        int dataIndex = 0;
        int dataBit = 0;
        int height = bitmap.getHeight();
        int width = bitmap.getWidth();
        int[] pixels = thresholdBitmapPixels(bitmap, shake);
        for (int x = 0; x < width; x++) {
            int y = 0;
            while (y < height) {
                if ((pixels[(width * y) + x] & 255) > 127) {
                    dataBit = (dataBit << 1) & 254;
                } else {
                    dataBit = (dataBit << 1) | 1;
                }
                y++;
                if (y % 8 == 0) {
                    int i = dataIndex;
                    dataIndex++;
                    data[i] = (byte) dataBit;
                    dataBit = 0;
                }
            }
        }
        return data;
    }

    public static int[] thresholdBitmapPixels(Bitmap bitmap, boolean shake) {
        int e;
        Bitmap bitmap2 = convertGrayBitmapByColorFilter(bitmap);
        int width = bitmap2.getWidth();
        int height = bitmap2.getHeight();
        int[] pixels = new int[width * height];
        bitmap2.getPixels(pixels, 0, width, 0, 0, width, height);
        if (shake) {
            int[] grays = Arrays.copyOf(pixels, pixels.length);
            for (int i = 0; i < grays.length; i++) {
                grays[i] = (grays[i] >> 16) & 255;
            }
            for (int i2 = 0; i2 < height; i2++) {
                for (int j = 0; j < width; j++) {
                    int px = grays[(width * i2) + j] & 255;
                    if (px >= 128) {
                        pixels[(width * i2) + j] = -1;
                        e = px - 255;
                    } else {
                        pixels[(width * i2) + j] = -16777216;
                        e = px - 0;
                    }
                    if (j < width - 1 && i2 < height - 1) {
                        int i3 = (width * i2) + j + 1;
                        grays[i3] = grays[i3] + ((7 * e) / 16);
                        int i4 = (width * (i2 + 1)) + j;
                        grays[i4] = grays[i4] + ((5 * e) / 16);
                        int i5 = (width * (i2 + 1)) + j + 1;
                        grays[i5] = grays[i5] + (e / 16);
                        if (j > 0) {
                            int i6 = ((width * (i2 + 1)) + j) - 1;
                            grays[i6] = grays[i6] + ((3 * e) / 16);
                        }
                    } else if (j == width - 1 && i2 < height - 1) {
                        int i7 = (width * (i2 + 1)) + j;
                        grays[i7] = grays[i7] + ((5 * e) / 16);
                    } else if (j < width - 1 && i2 == height - 1) {
                        int i8 = (width * i2) + j + 1;
                        grays[i8] = grays[i8] + ((7 * e) / 16);
                    }
                }
            }
        } else {
            for (int i9 = 0; i9 < pixels.length; i9++) {
                int r = (pixels[i9] >> 16) & 255;
                int g = (pixels[i9] >> 8) & 255;
                int b = pixels[i9] & 255;
                int gr = (int) ((r * 0.3f) + (g * 0.59f) + (b * 0.11f));
                if (gr >= 128) {
                    pixels[i9] = -1;
                } else {
                    pixels[i9] = -16777216;
                }
            }
        }
        return pixels;
    }

    public static Bitmap convertGrayBitmapByColorFilter(Bitmap bitmap) {
        int height = bitmap.getHeight();
        int width = bitmap.getWidth();
        Bitmap grayBitmap = Bitmap.createBitmap(width, height, Bitmap.Config.RGB_565);
        Canvas c = new Canvas(grayBitmap);
        c.drawColor(-1);
        Paint paint = new Paint();
        ColorMatrix cm = new ColorMatrix();
        cm.setSaturation(0.0f);
        ColorMatrixColorFilter f = new ColorMatrixColorFilter(cm);
        paint.setColorFilter(f);
        c.drawBitmap(bitmap, 0.0f, 0.0f, paint);
        return grayBitmap;
    }
}
